/* Determines the system language and attempts to run the matching DB2       */
/* Install language version.  A specific language can also be specified at   */
/* the command prompt using the /i:ll switch where ll is the two letter      */
/* language code.  Any errors will result in the English install being       */
/* launched.                                                                 */
/*                                                                           */
/* Note that the system language determination is based on the LANG          */
/* environment variable which was not always set with OS/2 v3.               */

Parse Source . . me
Parse Arg args

Lang = ''

/* Look for /i:ll command line parameter, if specified language is not */
/* supported then default to en                                        */
instargs = ''
Do While args <> ''
  Parse Var args a args
  If TRANSLATE( a ) = '/I' | TRANSLATE( a ) = '-I' Then Do
    Parse Var args Lang args
    Lang = TRANSLATE( Lang )
  End
  Else If TRANSLATE( LEFT( a, 3 ) ) = '/I:' |,
          TRANSLATE( LEFT( a, 3 ) ) = '-I:' Then Do
    Lang = TRANSLATE( SUBSTR( a, 4 ) )
  End
  Else instargs = instargs a
End


/* If the language was not specified in the command line then try  */
/* to determine system language from the LANG environment variable */
If Lang = '' Then Do
  Lang = TRANSLATE( VALUE( 'lang',,'OS2ENVIRONMENT' ) )
  If Lang = '' Then Lang = 'EN'
  Else If LEFT( Lang, 2 ) = 'AR' Then Lang = ''          /* Arabic */
  Else If LEFT( Lang, 2 ) = 'BG' Then Lang = 'BG'        /* Bulgarian */
  Else If LEFT( Lang, 2 ) = 'CA' Then Lang = ''          /* Catalanian */
  Else If LEFT( Lang, 2 ) = 'CS' Then Lang = 'CZ'        /* Czech */
  Else If LEFT( Lang, 2 ) = 'DA' Then Lang = 'DK'        /* Danish */
  Else If LEFT( Lang, 2 ) = 'DE' Then Lang = 'DE'        /* German */
  Else If LEFT( Lang, 2 ) = 'EL' Then Lang = 'GR'        /* Greek */
  Else If LEFT( Lang, 2 ) = 'EN' Then Lang = 'EN'        /* English */
  Else If LEFT( Lang, 2 ) = 'ES' Then Lang = 'ES'        /* Spanish */
  Else If LEFT( Lang, 2 ) = 'ET' Then Lang = ''          /* Estonian */
  Else If LEFT( Lang, 2 ) = 'FI' Then Lang = 'FI'        /* Finnish */
  Else If LEFT( Lang, 2 ) = 'FR' Then Lang = 'FR'        /* French */
  Else If LEFT( Lang, 2 ) = 'HR' Then Lang = ''          /* Croatian */
  Else If LEFT( Lang, 2 ) = 'HU' Then Lang = 'HU'        /* Hungarian */
  Else If LEFT( Lang, 2 ) = 'IS' Then Lang = ''          /* Icelandic */
  Else If LEFT( Lang, 2 ) = 'IT' Then Lang = 'IT'        /* Italian */
  Else If LEFT( Lang, 2 ) = 'IW' Then Lang = ''          /* Hebrew */
  Else If LEFT( Lang, 2 ) = 'JA' Then Lang = 'JP'        /* Japanese */
  Else If LEFT( Lang, 2 ) = 'KO' Then Lang = 'KR'        /* Korean */
  Else If LEFT( Lang, 2 ) = 'LT' Then Lang = ''          /* Lithuanian */
  Else If LEFT( Lang, 2 ) = 'LV' Then Lang = ''          /* Latvian */
  Else If LEFT( Lang, 2 ) = 'MK' Then Lang = ''          /* Macedonian */
  Else If LEFT( Lang, 2 ) = 'NL' Then Lang = 'NL'        /* Dutch */
  Else If LEFT( Lang, 2 ) = 'NO' Then Lang = 'NO'        /* Norwegian */
  Else If LEFT( Lang, 2 ) = 'PL' Then Lang = 'PL'        /* Polish */
  Else If Lang = 'PT_BR'         Then Lang = 'BR'        /* Brazilian */
  Else If Lang = 'PT_PT'         Then Lang = 'PT'        /* Portuguese */
  Else If LEFT( Lang, 2 ) = 'RO' Then Lang = ''          /* Romanian */
  Else If LEFT( Lang, 2 ) = 'RU' Then Lang = 'RU'        /* Russian */
  Else If LEFT( Lang, 2 ) = 'SH' Then Lang = ''          /* Bosnian */
  Else If LEFT( Lang, 2 ) = 'SK' Then Lang = ''          /* Slovakian */
  Else If LEFT( Lang, 2 ) = 'SL' Then Lang = 'SI'        /* Slovenian */
  Else If LEFT( Lang, 2 ) = 'SQ' Then Lang = ''          /* Albanian */
  Else If LEFT( Lang, 2 ) = 'SR' Then Lang = ''          /* Serbian */
  Else If LEFT( Lang, 2 ) = 'SV' Then Lang = 'SE'        /* Swedish */
  Else If LEFT( Lang, 2 ) = 'TH' Then Lang = ''          /* Thai */
  Else If LEFT( Lang, 2 ) = 'TR' Then Lang = 'TR'        /* Turkish */
  Else If Lang = 'ZH_CN'         Then Lang = 'CN'        /* Simplified Chinese */
  Else If Lang = 'ZH_TW'         Then Lang = 'TW'        /* Traditional Chinese */
  Else                                Lang = ''
End


/* Find the directory from which this program is runnning */
p = LASTPOS( '\', me )
If p > 0 Then mydir = LEFT( me, p-1 )
else mydir = ''


/* Determine location of language subdirectories executable */
If DirectoryExists( mydir || "\db2" ) Then
   basedir = mydir || "\db2"
Else
   basedir = mydir

/* Client paks, SDK pak are in an OS2 subdirectory. */
If DirectoryExists( basedir || "\os2" ) Then
   basedir = basedir || "\os2"


/* If language not determined then default to English */
If Lang = '' Then Lang = 'EN'

instpath=basedir || '\' || Lang || '\install'

If DirectoryExists(instpath) <> 0 Then
  Do   
/* If installing rtcl then don't add the -i lang param */

    If FileExists(instpath || '\db2rtcl.icf') = 0 Then
      instargs = ' -i ' || Lang || ' ' || instargs
  End
else
Lang = 'EN' /* Can't find lang path so reset to English */

/* Check for existence of language support on CD, if not found then default */
/* to English.                                                              */
installpgm = basedir || '\' || Lang || '\install\install.exe'
If FileExists( installpgm ) = 0 Then
   installpgm = basedir || '\en\install\install.exe'


/* Final check to see if selected install program exists, this shouldn't fail */
If FileExists( installpgm ) Then
   '@' || installpgm instargs
Else           /* No English?  Shouldn't get here, display command and error */
   installpgm instargs
exit rc




FileExists: Procedure
  Arg a
  If DirectoryExists( a ) = 0 Then Do
    '@dir "'a'"1>nul 2>nul'
    If rc = 0 Then return 1
  End

  Return 0

DirectoryExists: Procedure
  Arg a
  '@dir /ad "'a'\." 1>nul 2>nul'
  If rc = 0 Then return 1

  Return 0
